# Third-Party Notices

このリポジトリには、第三者が著作権を有するソフトウェアの **同梱（vendor）** および
**翻訳・参考実装** が含まれます。配布物（wheel / sdist）には、各ライセンス条項に従い
必要な表記を含めます。

## qMRLab

- Upstream: `qMRLab`（MATLAB 実装）
- Copyright (c) 2017 NeuroPoly
- License: MIT License
- Reference materials: ローカル参照（同梱なし）
- Notes: 本リポジトリは qMRLab の概念・モデル定義を **翻訳/再構成** しています。
  qMRLab 本体や `External/` 配下の第三者コードは同梱しておらず、取り込みが発生した場合は
  その都度ライセンス表記を追加します。

```
MIT License

Copyright (c) 2017 NeuroPoly

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```

## DECAES.jl

- Upstream: `DECAES.jl`
- Copyright (c) 2019 Jonathan Doucette
- License: MIT License
- Reference materials: ローカル参照（同梱なし）
- Notes: 一部アルゴリズム/実装の **翻訳・参考** を含む

```
Copyright (c) 2019 Jonathan Doucette

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
```
